@@ -43,7 +43,8 @@ class CourseModel:
             return ''
         return ', '.join(self.periods_taught)
 
-    def to_cv_list(self) -> List[str]:
+    @property
+    def name_score_description(self) -> str:
         if self.highlight_description is not None:
             desc = self.highlight_description
         else:
@@ -61,8 +62,4 @@ class CourseModel:
 
         name_score_desc_str = f'{self.title}{extra_info}'
 
-        return [
-            name_score_desc_str,
-            self.periods_taught_str
-        ]
-
+        return name_score_desc_str
