@@ -1,6 +1,6 @@
 from weakref import WeakSet
 from dataclasses import dataclass, field
-from typing import Optional, Sequence, List, Set, Callable
+from typing import Optional, Sequence, List, Set, Callable, Union, cast
 
 from weakreflist import WeakList
 
@@ -10,7 +10,7 @@ from derobertis_cv.models.nested import NestedModel
 from derobertis_cv.pltemplates.logo import HasLogo
 
 
-@dataclass(frozen=True)
+@dataclass(unsafe_hash=True)
 class SkillModel(CasedModel, NestedModel, HasLogo):
     title: str
     level: int
@@ -22,8 +22,22 @@ class SkillModel(CasedModel, NestedModel, HasLogo):
     case_lower_func: Callable[[str], str] = lambda x: x.lower()
     case_title_func: Callable[[str], str] = lambda x: x.title()
     case_capitalize_func: Callable[[str], str] = lambda x: x.capitalize()
-    parents: Optional[Sequence['NestedModel']] = field(default_factory=lambda: [])
-    children: WeakList = field(default_factory=lambda: WeakList())
+    parents: Optional[Sequence['NestedModel']] = tuple()
+    children: WeakList = field(default_factory=lambda: WeakList(), hash=False)
+    primary_category: Optional[Union['SkillModel', str]] = None
 
     def __post_init__(self):
         super().__init__()
+
+    @property
+    def category(self) -> 'SkillModel':
+        if self.primary_category is not None:
+            if self.primary_category == 'self':
+                return self
+            elif isinstance(self.primary_category, str):
+                raise ValueError('only str passed for primary_category should be self')
+            return self.primary_category
+        if self.parents:
+            return cast('SkillModel', self.parents[0])
+        return self
+
