@@ -5,6 +5,7 @@ from derobertis_cv import plbuild
 from derobertis_cv.plbuild.paths import images_path
 from derobertis_cv.pldata.constants.contact import CONTACT_LINES
 from derobertis_cv.pldata.cv import CVModel, get_cv_contents, ResumeSection
+from derobertis_cv.pldata.jobs import CV_JOB_MODIFIERS, CV_EXCLUDED_COMPANIES
 from derobertis_cv.pldata.software.config import ACADEMIC_INCLUDED_SOFTWARE_PROJECTS
 
 AUTHORS = ['Nick DeRobertis']
@@ -37,6 +38,8 @@ def get_content():
         SECTIONS,
         included_software_projects=ACADEMIC_INCLUDED_SOFTWARE_PROJECTS,
         professional_section_name='Other Professional Experience',
+        modify_job_descriptions=CV_JOB_MODIFIERS,
+        excluded_companies=CV_EXCLUDED_COMPANIES,
     )
     contents = get_cv_contents(model)
     return contents
