@@ -5,6 +5,8 @@ from derobertis_cv import plbuild
 from derobertis_cv.plbuild.paths import images_path
 from derobertis_cv.pldata.constants.contact import CONTACT_LINES
 from derobertis_cv.pldata.cv import CVModel, get_cv_contents, ResumeSection
+from derobertis_cv.pldata.jobs import CV_JOB_MODIFIERS, CV_EXCLUDED_COMPANIES
+from derobertis_cv.pldata.skills import CV_RENAME_SKILLS, CV_EXCLUDE_SKILLS, CV_SKILL_SECTION_ORDER
 from derobertis_cv.pldata.software.config import EXCLUDED_SOFTWARE_PROJECTS, PROFESSIONAL_SOFTWARE_PROJECT_ORDER
 
 AUTHORS = ['Nick DeRobertis']
@@ -21,8 +23,9 @@ SECTIONS = [
     pl.VSpace(0.2),
     ResumeSection.PROFESSIONAL_EXPERIENCE,
     ResumeSection.ACADEMIC_EXPERIENCE,
+    pl.PageBreak(),
     ResumeSection.SKILLS,
-    pl.VSpace(0.2),
+    pl.PageBreak(),
     ResumeSection.WORKING_PAPERS,
     pl.VSpace(0.2),
     ResumeSection.WORKS_IN_PROGRESS,
@@ -39,6 +42,12 @@ def get_content():
         excluded_software_projects=EXCLUDED_SOFTWARE_PROJECTS,
         software_project_order=PROFESSIONAL_SOFTWARE_PROJECT_ORDER,
         include_private_jobs=True,
+        rename_skills=CV_RENAME_SKILLS,
+        exclude_skills=CV_EXCLUDE_SKILLS,
+        skill_section_order=CV_SKILL_SECTION_ORDER,
+        include_working_paper_descriptions=False,
+        modify_job_descriptions=CV_JOB_MODIFIERS,
+        excluded_companies=CV_EXCLUDED_COMPANIES,
     )
     contents = get_cv_contents(model)
     return contents
