@@ -1,6 +1,7 @@
 
 AT_WARRINGTON = '@warrington.ufl.edu'
 ASSISTANT_PROF = 'Assistant Professor'
+ASSOCIATE_PROF_OF_FINANCE = 'Associate Professor of Finance'
 
 # Keys to reference authors
 ANDY = 'andy'
@@ -9,3 +10,4 @@ NITISH = 'nitish'
 SUGATA = 'sugata'
 CORBIN = 'corbin'
 JIMMY = 'jimmy'
+BAOLIAN = 'baolian'
