@@ -1,6 +1,6 @@
 from dataclasses import dataclass
 from enum import Enum
-from typing import List, Sequence, Optional, Union
+from typing import List, Sequence, Optional, Union, Dict, Callable
 
 import pyexlatex as pl
 import pyexlatex.resume as lr
@@ -9,6 +9,7 @@ from pyexlatex.models.item import ItemBase
 
 from derobertis_cv.plbuild.paths import images_path
 from derobertis_cv.pldata.constants.contact import STYLED_SITE
+from derobertis_cv.pldata.employment_model import JobIDs
 from derobertis_cv.pldata.jobs import (
     get_professional_jobs,
     get_academic_jobs
@@ -23,6 +24,7 @@ from derobertis_cv.pldata.software import get_software_projects
 from derobertis_cv.pldata.awards import get_awards
 from derobertis_cv.pldata.interests import get_research_interests
 from derobertis_cv.pldata.references import get_references
+from derobertis_cv.pltemplates.skills.section import SkillsSection
 from derobertis_cv.pltemplates.software.section import SoftwareSection
 
 
@@ -48,8 +50,10 @@ class CVModel:
     software_project_order: Optional[Sequence[str]] = None
     excluded_companies: Optional[Sequence[str]] = None
     exclude_skills: Optional[Sequence[str]] = None
-    exclude_skill_children: bool = True
+    exclude_skill_children: bool = False
     skill_order: Optional[Sequence[str]] = None
+    skill_section_order: Optional[Sequence[str]] = None
+    rename_skills: Optional[Dict[str, str]] = None
     professional_section_name: str = 'Professional Experience'
     overview_text: str = (
         'An entrepreneur, full-stack web engineer and architect, data scientist, empirical researcher, and '
@@ -57,6 +61,9 @@ class CVModel:
         'closed-source applications and research projects.'
     )
     include_private_jobs: bool = False
+    include_working_paper_descriptions: bool = True
+    include_wip_descriptions: bool = False
+    modify_job_descriptions: Optional[Dict[JobIDs, Callable[[Sequence[str]], Sequence[str]]]] = None
 
     def __post_init__(self):
         if self.software_project_order is None and self.included_software_projects is not None:
@@ -73,9 +80,15 @@ def get_cv_contents(model: CVModel) -> List[ItemBase]:
         job.to_pyexlatex_employment() for job in get_professional_jobs(
             excluded_companies=model.excluded_companies,
             include_private=model.include_private_jobs,
+            modify_descriptions=model.modify_job_descriptions,
+        )
+    ]
+    lr_academic_jobs = [
+        job.to_pyexlatex_employment() for job in get_academic_jobs(
+            excluded_companies=model.excluded_companies,
+            modify_descriptions=model.modify_job_descriptions,
         )
     ]
-    lr_academic_jobs = [job.to_pyexlatex_employment() for job in get_academic_jobs()]
     lr_education = [edu.to_pyexlatex() for edu in get_education()]
 
     all_contents = {
@@ -96,11 +109,17 @@ def get_cv_contents(model: CVModel) -> List[ItemBase]:
             title=model.professional_section_name
         ),
         ResumeSection.WORKING_PAPERS: lr.SpacedSection(
-            ResearchProjectModel.list_to_pyexlatex_publication_list(get_working_papers()),
+            ResearchProjectModel.list_to_pyexlatex_publication_list(
+                get_working_papers(),
+                include_descriptions=model.include_working_paper_descriptions,
+            ),
             title='Working Papers'
         ),
         ResumeSection.WORKS_IN_PROGRESS: lr.SpacedSection(
-            ResearchProjectModel.list_to_pyexlatex_publication_list(get_works_in_progress()),
+            ResearchProjectModel.list_to_pyexlatex_publication_list(
+                get_works_in_progress(),
+                include_descriptions=model.include_wip_descriptions,
+            ),
             title='Works in Progress'
         ),
         ResumeSection.AWARDS_GRANTS: lr.SpacedSection(
@@ -124,13 +143,14 @@ def get_cv_contents(model: CVModel) -> List[ItemBase]:
             title='References',
             num_cols=2
         ),
-        ResumeSection.SKILLS: pl.Section(
-            get_skills_str_list(
+        ResumeSection.SKILLS: SkillsSection(
+            get_skills(
                 exclude_skills=model.exclude_skills,
                 exclude_skill_children=model.exclude_skill_children,
                 order=model.skill_order,
+                rename_skills=model.rename_skills,
             ),
-            title='Skills'
+            section_order=model.skill_section_order,
         ),
         ResumeSection.OVERVIEW: pl.Section(
             model.overview_text,
