@@ -13,14 +13,19 @@ def _recursive_sort_skills(skills: List[SkillModel], **sort_kwargs):
     for skill in skills:
         _recursive_sort_skills(skill.children, **sort_kwargs)
 
+# Pure categories
+SOFT_SKILLS = SkillModel('Soft Skills', 5)
+OTHER = SkillModel('Other', 3)
 
+# Skills
 PROGRAMMING_SKILL = SkillModel('Programming', 5)
-SOFTWARE_ARCHITECTURE_SKILL = SkillModel('software architecture', 4)
-OS_SKILL = SkillModel('operating systems', 3)
-HARDWARE_SKILL = SkillModel('computer hardware', 3)
+PRESENTATION_SKILL = SkillModel('presentation', 4)
+SOFTWARE_ARCHITECTURE_SKILL = SkillModel('software architecture', 4, primary_category=PROGRAMMING_SKILL)
+OS_SKILL = SkillModel('operating systems', 3, primary_category=OTHER)
+HARDWARE_SKILL = SkillModel('computer hardware', 3, primary_category=OTHER)
 SOFTWARE_DEVELOPMENT_SKILL = SkillModel('software development', 5, parents=(PROGRAMMING_SKILL,))
-FRONTEND_SKILL = SkillModel('Front-end Development', 4, parents=(SOFTWARE_DEVELOPMENT_SKILL, SOFTWARE_ARCHITECTURE_SKILL))
-BACKEND_SKILL = SkillModel('Back-end Development', 5, parents=(SOFTWARE_DEVELOPMENT_SKILL, SOFTWARE_ARCHITECTURE_SKILL))
+FRONTEND_SKILL = SkillModel('Front-end Development', 4, parents=(SOFTWARE_DEVELOPMENT_SKILL, SOFTWARE_ARCHITECTURE_SKILL), primary_category=PROGRAMMING_SKILL)
+BACKEND_SKILL = SkillModel('Back-end Development', 5, parents=(SOFTWARE_DEVELOPMENT_SKILL, SOFTWARE_ARCHITECTURE_SKILL), primary_category=PROGRAMMING_SKILL)
 CLI_SKILL = SkillModel(
     'CLI Development',
     3,
@@ -28,72 +33,75 @@ CLI_SKILL = SkillModel(
     case_capitalize_func=first_word_untouched_rest_capitalized,
     case_lower_func=first_word_untouched_rest_lower,
     case_title_func=first_word_untouched_rest_title,
+    primary_category=PROGRAMMING_SKILL,
 )
 DATABASE_SKILL = SkillModel('Databases', 4, parents=(PROGRAMMING_SKILL,))
-DEV_OPS_SKILL = SkillModel('Dev-Ops', 4, parents=(PROGRAMMING_SKILL,))
+DEV_OPS_SKILL = SkillModel('Dev-Ops', 4, parents=(PROGRAMMING_SKILL,), primary_category='self')
 REMOTE_DEVELOPMENT_SKILL = SkillModel('Remote development', 3, parents=(PROGRAMMING_SKILL,))
 SECURITY_SKILL = SkillModel('Security', 3, parents=(PROGRAMMING_SKILL, SOFTWARE_ARCHITECTURE_SKILL))
 WEB_DEVELOPMENT_SKILL = SkillModel(
     'Web Development',
     4,
     parents=(SOFTWARE_DEVELOPMENT_SKILL, SOFTWARE_ARCHITECTURE_SKILL, REMOTE_DEVELOPMENT_SKILL, SECURITY_SKILL),
+    primary_category=PROGRAMMING_SKILL,
 )
-CSS_SKILL = SkillModel('CSS', 3, parents=(WEB_DEVELOPMENT_SKILL, FRONTEND_SKILL), flexible_case=False)
+CSS_SKILL = SkillModel('CSS', 4, parents=(WEB_DEVELOPMENT_SKILL, FRONTEND_SKILL), flexible_case=False, primary_category=PRESENTATION_SKILL)
 FRAMEWORK_SKILL = SkillModel('Frameworks', 5, parents=(PROGRAMMING_SKILL,))
 DEBUGGING_SKILL = SkillModel('Debugging', 4, parents=(PROGRAMMING_SKILL,))
 TESTING_SKILL = SkillModel('Automated testing', 4, parents=(PROGRAMMING_SKILL,))
 PARALLELISM_SKILL = SkillModel('Parallelism', 4, parents=(PROGRAMMING_SKILL,))
 CRYPTOGRAPHY_SKILL = SkillModel('Cryptography', 3, parents=(PROGRAMMING_SKILL, SECURITY_SKILL))
 ASYNC_SKILL = SkillModel('Asynchronous Programming', 4, parents=(PROGRAMMING_SKILL,))
-DISTRIBUTED_SKILL = SkillModel('Distributed Computing', 4, parents=(REMOTE_DEVELOPMENT_SKILL,))
-EXCEL_SKILL = SkillModel('Excel', 4, flexible_case=False)
+DISTRIBUTED_SKILL = SkillModel('Distributed Computing', 4, parents=(REMOTE_DEVELOPMENT_SKILL,), primary_category=PROGRAMMING_SKILL)
+EXCEL_SKILL = SkillModel('Excel', 4, flexible_case=False, primary_category=OTHER)
 AUTOMATION_SKILL = SkillModel('automation', 5, parents=(PROGRAMMING_SKILL,))
 SERVER_ADMIN_SKILL = SkillModel('server administration', 4, parents=(DEV_OPS_SKILL, WEB_DEVELOPMENT_SKILL))
 NETWORKING_SKILL = SkillModel('networking', 3, parents=(DEV_OPS_SKILL,))
 MONITORING_SKILL = SkillModel('application monitoring', 2, parents=(DEV_OPS_SKILL,))
 CI_SKILL = SkillModel('CI/CD', 4, parents=(DEV_OPS_SKILL,), flexible_case=False)
-SEO_SKILL = SkillModel('SEO', 2, parents=(WEB_DEVELOPMENT_SKILL,), flexible_case=False)
-CMS_SKILL = SkillModel('CMS', 4, parents=(WEB_DEVELOPMENT_SKILL,), flexible_case=False)
-MIGRATIONS_SKILL = SkillModel('migrations', 5, parents=(DATABASE_SKILL,))
+SEO_SKILL = SkillModel('SEO', 2, parents=(WEB_DEVELOPMENT_SKILL,), flexible_case=False, primary_category=PROGRAMMING_SKILL)
+CMS_SKILL = SkillModel('CMS', 4, parents=(WEB_DEVELOPMENT_SKILL,), flexible_case=False, primary_category=PROGRAMMING_SKILL)
+MIGRATIONS_SKILL = SkillModel('migrations', 5, parents=(DATABASE_SKILL,), primary_category=PROGRAMMING_SKILL)
 IDE_SKILL = SkillModel('IDEs', 4, parents=(PROGRAMMING_SKILL,), flexible_case=False)
 
 
-LINUX_SKILL = SkillModel('Linux', 4, parents=(OS_SKILL,), flexible_case=False)
-WINDOWS_SKILL = SkillModel('Windows', 4, parents=(OS_SKILL,), flexible_case=False)
+LINUX_SKILL = SkillModel('Linux', 4, parents=(OS_SKILL,), flexible_case=False, primary_category=OTHER)
+WINDOWS_SKILL = SkillModel('Windows', 4, parents=(OS_SKILL,), flexible_case=False, primary_category=OTHER)
 
-PRESENTATION_SKILL = SkillModel('presentation', 4)
 TYPE_SETTING_SKILL = SkillModel('Typesetting', 4, parents=(PRESENTATION_SKILL,))
-WRITING_SKILL= SkillModel('Writing', 4)
+WRITING_SKILL= SkillModel('Writing', 4, primary_category=PRESENTATION_SKILL)
 RESEARCH_SKILL = SkillModel('Research', 5)
-STATISTICS_SKILL = SkillModel('Statistics', 5)
-MODELING_SKILL = SkillModel('Modeling', 4)
-VERSION_CONTORL_SKILL = SkillModel('Version Control', 4)
-COLLABORATION_SKILL = SkillModel('Collaboration', 5)
-ENTREPRENEURSHIP_SKILL = SkillModel('Entrepreneurship', 5)
+DATA_SCIENCE_SKILL = SkillModel(
+    'Data Science',
+    4,
+    parents=(PROGRAMMING_SKILL, RESEARCH_SKILL),
+    primary_category='self'
+)
+STATISTICS_SKILL = SkillModel('Statistics', 5, parents=(DATA_SCIENCE_SKILL,))
+MODELING_SKILL = SkillModel('Modeling', 4, parents=(DATA_SCIENCE_SKILL,))
+VERSION_CONTORL_SKILL = SkillModel('Version Control', 4, parents=(PROGRAMMING_SKILL,))
+COLLABORATION_SKILL = SkillModel('Collaboration', 5, primary_category=SOFT_SKILLS)
+ENTREPRENEURSHIP_SKILL = SkillModel('Entrepreneurship', 5, primary_category=SOFT_SKILLS)
 PARSING_SKILL = SkillModel('Parsing', 4, parents=(PROGRAMMING_SKILL,))
-TIME_SERIES_SKILL = SkillModel('Time-Series', 3, parents=(STATISTICS_SKILL,))
-FORECASTING_SKILL = SkillModel('Forecasting', 3, parents=(TIME_SERIES_SKILL,))
+TIME_SERIES_SKILL = SkillModel('Time-Series', 3, parents=(STATISTICS_SKILL,), primary_category=DATA_SCIENCE_SKILL)
+FORECASTING_SKILL = SkillModel('Forecasting', 3, parents=(TIME_SERIES_SKILL,), primary_category=DATA_SCIENCE_SKILL)
 WEB_SCRAPING_SKILL = SkillModel('Web-scraping', 4, parents=(PROGRAMMING_SKILL, AUTOMATION_SKILL))
 DOCUMENTATION_SKILL = SkillModel('documentation', 4, parents=(PROGRAMMING_SKILL, PRESENTATION_SKILL, TYPE_SETTING_SKILL))
 TEMPLATING_SKILL = SkillModel('templating', 5, parents=(PROGRAMMING_SKILL, PRESENTATION_SKILL, TYPE_SETTING_SKILL))
 
 
 OPEN_SOURCE_SKILL = SkillModel('Open-Source Development', 5, parents=(PROGRAMMING_SKILL, COLLABORATION_SKILL))
-DATA_SCIENCE_SKILL = SkillModel(
-    'Data Science',
-    4,
-    parents=(PROGRAMMING_SKILL, RESEARCH_SKILL, STATISTICS_SKILL, MODELING_SKILL)
-)
+
 MACHINE_LEARNING_SKILL = SkillModel('machine learning', 3, parents=(DATA_SCIENCE_SKILL,))
 DATA_MUNGING_SKILL = SkillModel('data munging', 5, parents=(DATA_SCIENCE_SKILL,))
 DATA_ANALYSIS_SKILL = SkillModel('Data Analysis', 5, parents=(DATA_SCIENCE_SKILL,))
 VISUALIZATION_SKILL = SkillModel('visualization', 4, parents=(DATA_SCIENCE_SKILL, PRESENTATION_SKILL))
-PLOTTING_SKILL = SkillModel('plotting', 4, parents=(PROGRAMMING_SKILL, PRESENTATION_SKILL, VISUALIZATION_SKILL))
+PLOTTING_SKILL = SkillModel('plotting', 4, parents=(PROGRAMMING_SKILL, PRESENTATION_SKILL, VISUALIZATION_SKILL), primary_category=PRESENTATION_SKILL)
 
 
 PYTHON_SKILL = SkillModel('Python', 5, parents=(PROGRAMMING_SKILL,), flexible_case=False)
 JS_SKILL = SkillModel('JavaScript', 4, parents=(PROGRAMMING_SKILL,), flexible_case=False)
-TS_SKILL = SkillModel('TypeScript', 4, parents=(JS_SKILL,), flexible_case=False)
+TS_SKILL = SkillModel('TypeScript', 4, parents=(JS_SKILL,), flexible_case=False, primary_category=PROGRAMMING_SKILL)
 AWS_SKILL = SkillModel('AWS', 3, parents=(DEV_OPS_SKILL, WEB_DEVELOPMENT_SKILL, REMOTE_DEVELOPMENT_SKILL), flexible_case=False)
 
 DS_FRAMEWORK_SKILLS = (FRAMEWORK_SKILL, PYTHON_SKILL, DATA_SCIENCE_SKILL)
@@ -165,53 +173,54 @@ _SKILLS: List[SkillModel] = [
     HARDWARE_SKILL,
     IDE_SKILL,
     VISUALIZATION_SKILL,
-    SkillModel('SQL', 4, parents=(DATABASE_SKILL,), flexible_case=False),
-    SkillModel('Redis', 4, parents=(DATABASE_SKILL,), flexible_case=False),
-    SkillModel('Angular', 4, parents=FE_TS_WEB_FRAMEWORK_SKILLS, flexible_case=False),
-    SkillModel('React', 1, parents=FE_TS_WEB_FRAMEWORK_SKILLS, flexible_case=False),
+    SkillModel('SQL', 4, parents=(DATABASE_SKILL,), flexible_case=False, primary_category=PROGRAMMING_SKILL),
+    SkillModel('Redis', 4, parents=(DATABASE_SKILL,), flexible_case=False, primary_category=FRAMEWORK_SKILL),
+    SkillModel('Angular', 4, parents=FE_TS_WEB_FRAMEWORK_SKILLS, flexible_case=False, primary_category=FRAMEWORK_SKILL),
+    SkillModel('React', 1, parents=FE_TS_WEB_FRAMEWORK_SKILLS, flexible_case=False, primary_category=FRAMEWORK_SKILL),
     SkillModel('Docker', 4, parents=(DEV_OPS_SKILL,), flexible_case=False),
-    SkillModel('LaTeX', 4, parents=(TYPE_SETTING_SKILL, RESEARCH_SKILL), flexible_case=False),
+    SkillModel('LaTeX', 4, parents=(TYPE_SETTING_SKILL, RESEARCH_SKILL), flexible_case=False, primary_category=PRESENTATION_SKILL),
     SkillModel('SAS', 3, parents=(PROGRAMMING_SKILL,), flexible_case=False),
     SkillModel('Stata', 4, parents=(PROGRAMMING_SKILL,), flexible_case=False),
     SkillModel('MATLAB', 1, parents=(PROGRAMMING_SKILL,), flexible_case=False),
-    SkillModel('NoSQL', 2, parents=(DATABASE_SKILL,), flexible_case=False),
-    SkillModel('Git', 4, parents=(VERSION_CONTORL_SKILL,), flexible_case=False),
+    SkillModel('NoSQL', 2, parents=(DATABASE_SKILL,), flexible_case=False, primary_category=PROGRAMMING_SKILL),
+    SkillModel('Git', 4, parents=(VERSION_CONTORL_SKILL,), flexible_case=False, primary_category=PROGRAMMING_SKILL),
     SkillModel('Bash', 3, parents=(PROGRAMMING_SKILL,), flexible_case=False),
 
-    SkillModel('EC2', 4, parents=(AWS_SKILL, SERVER_ADMIN_SKILL), flexible_case=False),
-    SkillModel('RDS', 3, parents=(AWS_SKILL, DATABASE_SKILL), flexible_case=False),
-    SkillModel('VPC', 3, parents=(AWS_SKILL, NETWORKING_SKILL), flexible_case=False),
-    SkillModel('Route53', 3, parents=(AWS_SKILL, NETWORKING_SKILL), flexible_case=False),
-    SkillModel('S3', 3, parents=(AWS_SKILL, DATABASE_SKILL), flexible_case=False),
-    SkillModel('ElastiCache', 3, parents=(AWS_SKILL, DATABASE_SKILL), flexible_case=False),
-    SkillModel('IAM', 3, parents=(AWS_SKILL, COLLABORATION_SKILL), flexible_case=False),
-    SkillModel('CloudWatch', 3, parents=(AWS_SKILL, MONITORING_SKILL), flexible_case=False),
-    SkillModel('CloudFormation', 2, parents=(AWS_SKILL, SERVER_ADMIN_SKILL, NETWORKING_SKILL), flexible_case=False),
-    SkillModel('ECS', 3, parents=(AWS_SKILL, SERVER_ADMIN_SKILL), flexible_case=False),
-    SkillModel('CDK', 3, parents=(AWS_SKILL, SERVER_ADMIN_SKILL, NETWORKING_SKILL), flexible_case=False),
+    SkillModel('EC2', 4, parents=(AWS_SKILL, SERVER_ADMIN_SKILL), flexible_case=False, primary_category=DEV_OPS_SKILL),
+    SkillModel('RDS', 3, parents=(AWS_SKILL, DATABASE_SKILL), flexible_case=False, primary_category=DEV_OPS_SKILL),
+    SkillModel('VPC', 3, parents=(AWS_SKILL, NETWORKING_SKILL), flexible_case=False, primary_category=DEV_OPS_SKILL),
+    SkillModel('Route53', 3, parents=(AWS_SKILL, NETWORKING_SKILL), flexible_case=False, primary_category=DEV_OPS_SKILL),
+    SkillModel('S3', 3, parents=(AWS_SKILL, DATABASE_SKILL), flexible_case=False, primary_category=DEV_OPS_SKILL),
+    SkillModel('ElastiCache', 3, parents=(AWS_SKILL, DATABASE_SKILL), flexible_case=False, primary_category=DEV_OPS_SKILL),
+    SkillModel('IAM', 3, parents=(AWS_SKILL, COLLABORATION_SKILL), flexible_case=False, primary_category=DEV_OPS_SKILL),
+    SkillModel('CloudWatch', 3, parents=(AWS_SKILL, MONITORING_SKILL), flexible_case=False, primary_category=DEV_OPS_SKILL),
+    SkillModel('CloudFormation', 2, parents=(AWS_SKILL, SERVER_ADMIN_SKILL, NETWORKING_SKILL), flexible_case=False, primary_category=DEV_OPS_SKILL),
+    SkillModel('ECS', 3, parents=(AWS_SKILL, SERVER_ADMIN_SKILL), flexible_case=False, primary_category=DEV_OPS_SKILL),
+    SkillModel('CDK', 3, parents=(AWS_SKILL, SERVER_ADMIN_SKILL, NETWORKING_SKILL), flexible_case=False, primary_category=DEV_OPS_SKILL),
 
-    SkillModel('Nginx', 3, parents=(SERVER_ADMIN_SKILL,), flexible_case=False),
+    SkillModel('Nginx', 3, parents=(SERVER_ADMIN_SKILL,), flexible_case=False, primary_category=DEV_OPS_SKILL),
 
-    SkillModel('JIRA', 4, parents=(WEB_DEVELOPMENT_SKILL, COLLABORATION_SKILL), flexible_case=False),
+    SkillModel('JIRA', 4, parents=(WEB_DEVELOPMENT_SKILL, COLLABORATION_SKILL), flexible_case=False, primary_category=OTHER),
 
-    SkillModel('PyCharm', 4, parents=(IDE_SKILL,), flexible_case=False),
-    SkillModel('VS Code', 4, parents=(IDE_SKILL,), flexible_case=False),
+    SkillModel('PyCharm', 4, parents=(IDE_SKILL,), flexible_case=False, primary_category=PROGRAMMING_SKILL),
+    SkillModel('VS Code', 4, parents=(IDE_SKILL,), flexible_case=False, primary_category=PROGRAMMING_SKILL),
 
     SkillModel(
-        'empirical research', 5, parents=(RESEARCH_SKILL, STATISTICS_SKILL, DATA_ANALYSIS_SKILL, DATA_MUNGING_SKILL)
+        'empirical research', 5, parents=(RESEARCH_SKILL, STATISTICS_SKILL, DATA_ANALYSIS_SKILL, DATA_MUNGING_SKILL),
+        primary_category=DATA_SCIENCE_SKILL,
     ),
 
-    SkillModel('Github Actions', 4, parents=(CI_SKILL,), flexible_case=False),
-    SkillModel('Gitlab CI', 3, parents=(CI_SKILL,), flexible_case=False),
+    SkillModel('Github Actions', 4, parents=(CI_SKILL,), flexible_case=False, primary_category=DEV_OPS_SKILL),
+    SkillModel('Gitlab CI', 3, parents=(CI_SKILL,), flexible_case=False, primary_category=DEV_OPS_SKILL),
 
-    SkillModel('econometrics', 4, parents=(STATISTICS_SKILL,)),
-    SkillModel('project management', 4),
-    SkillModel('Quality assurance', 3),
-    SkillModel('HTML', 4, parents=(WEB_DEVELOPMENT_SKILL, FRONTEND_SKILL, TYPE_SETTING_SKILL), flexible_case=False),
-    SkillModel('Sass', 3, parents=(CSS_SKILL,), flexible_case=False),
-    SkillModel('Bootstrap', 3, parents=(CSS_SKILL, JS_SKILL, FRAMEWORK_SKILL), flexible_case=False),
-    SkillModel('Material Design', 2, parents=(CSS_SKILL, JS_SKILL, FRAMEWORK_SKILL), flexible_case=False),
-    SkillModel('jQuery', 2, parents=(JS_SKILL, FRAMEWORK_SKILL), flexible_case=False),
+    SkillModel('econometrics', 4, parents=(STATISTICS_SKILL,), primary_category=DATA_SCIENCE_SKILL),
+    SkillModel('project management', 4, primary_category=OTHER),
+    SkillModel('Quality assurance', 3, primary_category=OTHER),
+    SkillModel('HTML', 4, parents=(WEB_DEVELOPMENT_SKILL, FRONTEND_SKILL, TYPE_SETTING_SKILL), flexible_case=False, primary_category=PRESENTATION_SKILL),
+    SkillModel('Sass', 3, parents=(CSS_SKILL,), flexible_case=False, primary_category=FRAMEWORK_SKILL),
+    SkillModel('Bootstrap', 3, parents=(CSS_SKILL, JS_SKILL, FRAMEWORK_SKILL), flexible_case=False, primary_category=FRAMEWORK_SKILL),
+    SkillModel('Material Design', 2, parents=(CSS_SKILL, JS_SKILL, FRAMEWORK_SKILL), flexible_case=False, primary_category=FRAMEWORK_SKILL),
+    SkillModel('jQuery', 2, parents=(JS_SKILL, FRAMEWORK_SKILL), flexible_case=False, primary_category=FRAMEWORK_SKILL),
 
     SkillModel('pandas', 5, parents=DS_FRAMEWORK_SKILLS + (DATA_ANALYSIS_SKILL, DATA_MUNGING_SKILL), flexible_case=False),
     SkillModel('NumPy', 4, parents=DS_FRAMEWORK_SKILLS + (DATA_ANALYSIS_SKILL, DATA_MUNGING_SKILL), flexible_case=False),
@@ -250,18 +259,54 @@ _SKILLS: List[SkillModel] = [
 
     SkillModel('xlwings', 4, parents=(FRAMEWORK_SKILL, PYTHON_SKILL, EXCEL_SKILL, AUTOMATION_SKILL), flexible_case=False),
     SkillModel('fire', 3, parents=(FRAMEWORK_SKILL, PYTHON_SKILL, CLI_SKILL), flexible_case=False),
+
+    SkillModel(
+        'Bloomberg terminal',
+        2,
+        case_capitalize_func=first_word_untouched_rest_capitalized,
+        case_lower_func=first_word_untouched_rest_lower,
+        case_title_func=first_word_untouched_rest_title,
+        primary_category=OTHER
+    )
 ]
 
 _recursive_sort_skills(_SKILLS, key=lambda skill: skill.level, reverse=True)
 
 SKILLS: Dict[str, SkillModel] = {skill.to_lower_case_str(): skill for skill in _SKILLS}
 
+CV_RENAME_SKILLS: Dict[str, str] = {
+    'asynchronous programming': 'Async. Programming',
+    'open-source development': 'Open-Source',
+    'back-end development': 'Back-end dev.',
+    'front-end development': 'Front-end dev.',
+    'distributed computing': 'Distrib. Computing',
+    'application monitoring': 'App Monitoring',
+}
+
+CV_EXCLUDE_SKILLS: List[str] = [
+    'research',
+    'collaboration',
+    'entrepreneurship',
+]
+
+CV_SKILL_SECTION_ORDER: List[str] = [
+    'Programming',
+    'Data Science',
+    'Frameworks',
+    'Dev-Ops',
+    'Presentation',
+    'Other'
+]
+
 
 def get_skills(exclude_skills: Optional[Sequence[str]] = None,
                exclude_skill_children: bool = True,
-               order: Optional[Sequence[str]] = None) -> List[SkillModel]:
+               order: Optional[Sequence[str]] = None,
+               rename_skills: Optional[Dict[str, str]] = None) -> List[SkillModel]:
     if exclude_skills is None:
         exclude_skills = []
+    if rename_skills is None:
+        rename_skills = {}
 
     skills = [skill for key, skill in SKILLS.items() if key not in exclude_skills]
     if not exclude_skill_children:
@@ -275,6 +320,17 @@ def get_skills(exclude_skills: Optional[Sequence[str]] = None,
         child_excluded_skill_names = {child.to_lower_case_str() for child in child_excluded_skills}
         use_skills = [skill for skill in skills if skill.to_lower_case_str() not in child_excluded_skill_names]
 
+    if rename_skills:
+        new_use_skills: List[SkillModel] = []
+        for skill in use_skills:
+            if skill.to_lower_case_str() in rename_skills:
+                new_skill = deepcopy(skill)
+                new_skill.title = rename_skills[skill.to_lower_case_str()]
+                new_use_skills.append(new_skill)
+            else:
+                new_use_skills.append(skill)
+        use_skills = new_use_skills
+
     if order is not None:
         _recursive_sort_skills(
             use_skills,
